# shakeflow

[![Actions Status](https://github.com/shakeflow/shakeflow/actions/workflows/workflow.yml/badge.svg)](https://github.com/shakeflow/shakeflow/actions)
[![coverage](https://codecov.io/gh/shakeflow/shakeflow/branch/main/graph/badge.svg)](https://codecov.io/gh/shakeflow/shakeflow)
[![docs](https://img.shields.io/badge/docs-stable-blue.svg)](https://shakeflow.github.io/shakeflow/)
[![supported versions](https://img.shields.io/pypi/pyversions/shakeflow.svg?label=python_versions)](https://pypi.python.org/pypi/shakeflow)
[![docs](https://badge.fury.io/py/shakeflow.svg)](https://badge.fury.io/py/shakeflow)


Shake events locating and focal mechanism analysis.

## License
